@@ -3,62 +3,52 @@ package DBD::Sys::Plugin::Meta;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-use base qw(DBD::Sys::Plugin);
-
-$VERSION = 0.02;
+#################### main pod documentation start ###################
 
 =head1 NAME
 
 DBD::Sys::Plugin::Meta - provides tables with meta information about DBD::Sys.
 
-=head1 ISA
-
-  DBD::Sys::Plugin::Meta
-  ISA DBD::Sys::Plugin
-
-=head1 DESCRIPTION
-
-This plugin is created to manage the tables containing DBD::Sys meta data.
-
-=head2 TABLES
+=head1 TABLES
 
 Provided tables:
 
-=head3 alltables
+=over 8
 
-Table containing the list of available tables. See
-L<DBD::Sys::Plugin::Meta::AllTables> for details.
+=item alltables
 
-=head1 METHODS
+Table containing the list of available tables.
 
-=cut
+Columns:
 
-require DBD::Sys::Plugin::Meta::AllTables;
+=over 12
 
-my %supportedTables = ( alltables => 'DBD::Sys::Plugin::Meta::AllTables', );
+=item table_qualifier
 
-=head2 getSupportedTables
+Unused, I<NULL>.
 
-Delivers the supported meta tables.
+=item table_owner
 
-=cut
+Unused, I<NULL>
 
-sub getSupportedTables() { %supportedTables }
+=item table_name
 
-=head2 getPriority
+Name of the table
 
-Delivers the default priority for the meta tables, which is 100.
+=item table_type
 
-=cut
+Class name of the table implementation
 
-sub getPriority { return 100; }
+=item remarks
+
+Unused, I<NULL>
+
+=back
+
+=back
 
 =head1 PREREQUISITES
 
-The meta tables provide information about the tables in DBD::Sys, so
-their only requirement is DBD::Sys.
-
 =head1 BUGS & LIMITATIONS
 
 No known bugs at this moment.
@@ -68,7 +58,7 @@ No known bugs at this moment.
     Jens Rehsack			Alexander Breibach
     CPAN ID: REHSACK
     rehsack@cpan.org			alexander.breibach@googlemail.com
-    http://www.rehsack.de/
+    http://www.rehsack.de/		http://...
 
 =head1 COPYRIGHT
 
@@ -81,14 +71,44 @@ LICENSE file included with this module.
 =head1 SUPPORT
 
 Free support can be requested via regular CPAN bug-tracking system. There is
-no guaranteed reaction time or solution time, but it's always tried to give
-accept or reject a reported ticket within a week. It depends on business load.
+no guaranteed reaction time or solution time. It depends on business load.
 That doesn't mean that ticket via rt aren't handles as soon as possible,
 that means that soon depends on how much I have to do.
 
-Business and commercial support should be acquired from the authors via
+Business and commercial support should be aquired from the authors via
 preferred freelancer agencies.
 
 =cut
 
+#################### main pod documentation end ###################
+
+my %supportedTables = ( alltables => 'DBD::Sys::Plugin::Meta::AllTables', );
+
+sub getSupportedTables() { %supportedTables }
+
+package DBD::Sys::Plugin::Meta::AllTables;
+
+use strict;
+use warnings;
+use vars qw(@colNames);
+
+use base qw(DBD::Sys::Table);
+
+@colNames = qw(table_qualifier table_owner table_name table_type remarks);
+
+sub getColNames() { @colNames }
+
+sub collect_data()
+{
+    my @data;
+    my %tables = $_[0]->{owner}->getTableDetails();
+
+    while ( my ( $table, $class ) = each(%tables) )
+    {
+        push( @data, [ undef, undef, $table, 'TABLE', $class ] );
+    }
+
+    return \@data;
+}
+
 1;
